# include <OneWire.h>
# include <DallasTemperature.h>

class Temperature
{
  OneWire one;
  DallasTemperature sensors;

public:
  Temperature( int pin )
  {
    one.SetPin( pin );
    sensors.SetOneWire( &one );
    sensors.begin();
    sensors.setResolution( 12 );
  }

  int
  how_many_sensors( void )
  {
    return sensors.getDeviceCount();
  }

  void
  read( int index )
  {
    sensors.requestTemperaturesByIndex( index );
  }

  float
  celsius( int index )
  {
    return sensors.getTempCByIndex( index );
  }

  float
  fahrenheit( int index )
  {
    return sensors.getTempFByIndex( index );
  }
};

class Stats
{
  unsigned long n;
  double mean;
  double variance;
  double sum;
public:
  Stats( void )
  {
    n = 0; mean = 0; variance = 0; sum = 0;
  }
  void sample( double s )
  {
    double delta = s - mean;
    n++;
    mean += delta / n;
    sum += delta * delta;
  }
  double get_mean( void ) { return mean; }
  double get_variance( void ) { return sum / n; }
  double get_sd( void ) { return sqrt( sum / n ); }
  double get_snr( void ) { return get_mean() / get_sd(); }
};

